@@ -17,8 +17,9 @@ import sys
 
 import click
 
+from polyaxon import settings
 from polyaxon.cli.errors import handle_cli_error
-from polyaxon.logger import clean_outputs
+from polyaxon.deploy.schemas.deployment_types import DeploymentTypes
 from polyaxon.managers.client import ClientConfigManager
 from polyaxon.utils.formatting import Printer
 
@@ -29,21 +30,28 @@ from polyaxon.utils.formatting import Printer
 )
 @click.option(
     "--namespace",
-    type=int,
+    type=str,
     help="The namespace used for deploying Polyaxon, default polyaxon.",
 )
+@click.option(
+    "-t", "--deployment-type", help="Deployment type.",
+)
 @click.option(
     "--release",
-    type=int,
+    type=str,
     help="The release name used for deploying Polyaxon, default polyaxon.",
 )
-@clean_outputs
-def port_forward(port, namespace, release):
+def port_forward(port, namespace, deployment_type, release):
     """If you deploy Polyaxon using ClusterIP, you can use this command
     to access the gateway through `localhost:port`.
     """
     from polyaxon.deploy.operators.kubectl import KubectlOperator
 
+    if not port and deployment_type in [
+        DeploymentTypes.MICRO_K8S,
+        DeploymentTypes.MINIKUBE,
+    ]:
+        port = 31833
     port = port or 8000
     namespace = namespace or "polyaxon"
     release = release or "polyaxon"
@@ -70,5 +78,7 @@ def port_forward(port, namespace, release):
     ClientConfigManager.set_config(_config)
     Printer.print_header("Client configuration is updated!")
     Printer.print_success("Polyaxon will be available at: {}".format(_config.host))
-    stdout = kubectl.execute(args=args, is_json=False)
+    stdout = kubectl.execute(
+        args=args, is_json=False, stream=settings.CLIENT_CONFIG.debug
+    )
     click.echo(stdout)
