@@ -23,6 +23,7 @@ from polyaxon_sdk.rest import ApiException
 from urllib3.exceptions import HTTPError
 
 from polyaxon import settings
+from polyaxon.cli.dashboard import get_dashboard_url
 from polyaxon.cli.errors import handle_cli_error
 from polyaxon.cli.init import init as init_project
 from polyaxon.client import ProjectClient
@@ -37,7 +38,6 @@ from polyaxon.utils.formatting import (
     get_meta_response,
     list_dicts_to_tabulate,
 )
-from polyaxon.utils.http_utils import polyaxon_ui
 from polyaxon.utils.validation import validate_tags
 
 
@@ -73,6 +73,7 @@ def project(ctx, project):  # pylint:disable=redefined-outer-name
 )
 @click.option(
     "--owner",
+    "-o",
     type=str,
     help="Name of the owner/namespace, "
     "if not provided it will default to the namespace of the current user.",
@@ -119,6 +120,11 @@ def create(ctx, name, owner, description, tags, private, init):
     Printer.print_success(
         "Project `{}` was created successfully.".format(_project.name)
     )
+    click.echo(
+        "You can view this project on Polyaxon UI: {}".format(
+            get_dashboard_url(subpath="{}/{}".format(owner, _project.name))
+        )
+    )
 
     if init:
         ctx.obj = {}
@@ -128,13 +134,20 @@ def create(ctx, name, owner, description, tags, private, init):
 @project.command()
 @click.option(
     "--owner",
+    "-o",
     type=str,
     help="Name of the owner/namespace, "
     "if not provided it will default to the namespace of the current user.",
 )
+@click.option(
+    "--query", "-q", type=str, help="To filter the projects based on this query spec."
+)
+@click.option(
+    "--sort", "-s", type=str, help="To order the projects based on the sort spec."
+)
 @click.option("--limit", type=int, help="To limit the list of projects.")
 @click.option("--offset", type=int, help="To offset the list of projects.")
-def ls(owner, limit, offset):
+def ls(owner, query, sort, limit, offset):
     """List projects.
 
     Uses /docs/core/cli/#caching
@@ -149,7 +162,9 @@ def ls(owner, limit, offset):
 
     try:
         polyaxon_client = ProjectClient(owner=owner)
-        response = polyaxon_client.list(limit=limit, offset=offset)
+        response = polyaxon_client.list(
+            limit=limit, offset=offset, query=query, sort=sort
+        )
     except (ApiException, HTTPError) as e:
         handle_cli_error(e, message="Could not get list of projects.")
         sys.exit(1)
@@ -332,8 +347,7 @@ def update(ctx, name, description, private):
 def dashboard(ctx, yes, url):
     """Open this operation's dashboard details in browser."""
     owner, project_name = get_project_or_local(ctx.obj.get("project"), is_cli=True)
-    dashboard_url = polyaxon_ui(settings.CLIENT_CONFIG.host)
-    project_url = "{}/{}/{}/".format(dashboard_url, owner, project_name)
+    project_url = get_dashboard_url(subpath="{}/{}".format(owner, project_name))
     if url:
         Printer.print_header("The dashboard is available at: {}".format(project_url))
         sys.exit(0)
