@@ -18,6 +18,7 @@ import shutil
 
 import click
 
+from polyaxon import settings
 from polyaxon.client.transport import Transport
 from polyaxon.deploy.operators.compose import ComposeOperator
 from polyaxon.deploy.operators.docker import DockerOperator
@@ -25,21 +26,23 @@ from polyaxon.deploy.operators.helm import HelmOperator
 from polyaxon.deploy.operators.kubectl import KubectlOperator
 from polyaxon.deploy.schemas.deployment import DeploymentConfig
 from polyaxon.deploy.schemas.deployment_types import DeploymentCharts, DeploymentTypes
-from polyaxon.exceptions import PolyaxonException
+from polyaxon.exceptions import PolyaxonException, PolyaxonOperatorException
 from polyaxon.managers.compose import ComposeConfigManager
 from polyaxon.utils.formatting import Printer
 
 
-class DeployManager(object):
+class DeployManager:
     def __init__(
         self,
         config: DeploymentConfig = None,
         filepath=None,
+        deployment_type=False,
         manager_path=None,
         dry_run=False,
     ):
         self.config = config
         self.filepath = filepath
+        self.type = deployment_type
         self.manager_path = manager_path
         self.dry_run = dry_run
         self.kubectl = KubectlOperator()
@@ -49,6 +52,8 @@ class DeployManager(object):
 
     @property
     def deployment_type(self):
+        if self.type:
+            return self.type
         if self.config and self.config.deployment_type:
             return self.config.deployment_type
         return DeploymentTypes.KUBERNETES
@@ -174,15 +179,23 @@ class DeployManager(object):
 
     def _get_or_create_namespace(self):
         click.echo("Checking {} namespace ...".format(self.deployment_namespace))
-        stdout = self.kubectl.execute(
-            args=["get", "namespace", self.deployment_namespace], is_json=True,
-        )
+        try:
+            stdout = self.kubectl.execute(
+                args=["get", "namespace", self.deployment_namespace],
+                is_json=True,
+                stream=settings.CLIENT_CONFIG.debug,
+            )
+        except PolyaxonOperatorException:
+            stdout = None
+
         if stdout:
             return
         # Create a namespace
         click.echo("Creating {} namespace ...".format(self.deployment_namespace))
         stdout = self.kubectl.execute(
-            args=["create", "namespace", self.deployment_namespace], is_json=False,
+            args=["create", "namespace", self.deployment_namespace],
+            is_json=False,
+            stream=settings.CLIENT_CONFIG.debug,
         )
         click.echo(stdout)
 
@@ -198,13 +211,18 @@ class DeployManager(object):
         args += ["--namespace={}".format(self.deployment_namespace)]
         if self.filepath:
             args += ["-f", self.filepath]
+        if self.type in [DeploymentTypes.MICRO_K8S, DeploymentTypes.MINIKUBE]:
+            args += [
+                "--set",
+                "gateway.service.type=NodePort,deploymentType={}".format(self.type),
+            ]
         if self.deployment_version:
             args += ["--version", self.deployment_version]
         if self.dry_run:
             args += ["--debug", "--dry-run"]
 
         click.echo("Running install command ...")
-        stdout = self.helm.execute(args=args)
+        stdout = self.helm.execute(args=args, stream=settings.CLIENT_CONFIG.debug)
         click.echo(stdout)
         Printer.print_success("Deployment finished.")
 
@@ -274,13 +292,21 @@ class DeployManager(object):
             args += [self.k8s_chart]
         if self.filepath:
             args += ["-f", self.filepath]
+        if self.type and self.type in [
+            DeploymentTypes.MICRO_K8S,
+            DeploymentTypes.MINIKUBE,
+        ]:
+            args += [
+                "--set",
+                "gateway.service.type=NodePort,deploymentType={}".format(self.type),
+            ]
         if self.deployment_version:
             args += ["--version", self.deployment_version]
         args += ["--namespace={}".format(self.deployment_namespace)]
         if self.dry_run:
             args += ["--debug", "--dry-run"]
         click.echo("Running upgrade command ...")
-        stdout = self.helm.execute(args=args)
+        stdout = self.helm.execute(args=args, stream=settings.CLIENT_CONFIG.debug)
         click.echo(stdout)
         Printer.print_success("Deployment upgraded.")
 
