@@ -13,6 +13,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+
 import uuid
 
 from collections import namedtuple
@@ -130,7 +131,7 @@ class V1Param(BaseConfig, polyaxon_sdk.V1Param):
 
 
     When a param is passed from the CLI or directly in the YAML/Python specification,
-    it will be validated against the [inputs / outputs](/docs/core/specification/io/)
+    it will be validated against the [inputs/outputs](/docs/core/specification/io/)
     defined in the [component](/docs/core/specification/component/)
 
     Args:
@@ -237,8 +238,9 @@ class V1Param(BaseConfig, polyaxon_sdk.V1Param):
 
     ### contextOnly
 
-    A flag to signal to Polyaxon that this param should not be validated against the inputs / outputs,
-    and it's only used to resolve some information and inject it to the context.
+    A flag to signal to Polyaxon that this param should not be validated
+    against the inputs/outputs, and it's only used to resolve some
+    information and inject it into the context.
 
     ```yaml
     >>> params:
@@ -255,7 +257,7 @@ class V1Param(BaseConfig, polyaxon_sdk.V1Param):
     >>>          strides: [1, 1]
     ```
 
-    Polyaxon will not check if this param was required by an input / output,
+    Polyaxon will not check if this param was required by an input/output,
     and will inject it automatically in the context to be used.
     You can use for example `{{ convolutions.conv1 }}` in the specification.
     """
@@ -347,7 +349,7 @@ class V1Param(BaseConfig, polyaxon_sdk.V1Param):
             else:
                 value_parts = self.value
 
-            value_parts = value_parts.split(".")
+            value_parts = [s.strip() for s in value_parts.split(".")]
             if len(value_parts) > 3:
                 raise ValidationError(
                     "Could not parse value `{}` for param `{}`.".format(
