@@ -16,4 +16,4 @@
 
 import re
 
-PARAM_REGEX = re.compile(r"{{\s*([^\s]*)\s*}}")
+PARAM_REGEX = re.compile(r"{{\s*(.+)\s*}}")
