@@ -13,24 +13,23 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-
-import time
+import asyncio
+import os
 
 from kubernetes.client.rest import ApiException
 
 from polyaxon.client import RunClient
 from polyaxon.env_vars.getters import get_run_info
+from polyaxon.env_vars.keys import POLYAXON_KEYS_K8S_POD_ID
 from polyaxon.exceptions import PolyaxonClientException, PolyaxonContainerException
-from polyaxon.k8s.manager import K8SManager
-from polyaxon.k8s.monitor import is_pod_running
+from polyaxon.k8s.async_manager import AsyncK8SManager
 from polyaxon.logger import logger
 from polyaxon.settings import CLIENT_CONFIG
 from polyaxon.sidecar.intervals import get_sync_interval
-from polyaxon.sidecar.logging import sync_logs
-from polyaxon.sidecar.outputs import sync_artifacts, sync_summaries
+from polyaxon.sidecar.monitors import sync_artifacts, sync_summaries, sync_logs
 
 
-def start_sidecar(
+async def start_sidecar(
     container_id: str,
     sleep_interval: int,
     sync_interval: int,
@@ -40,6 +39,13 @@ def start_sidecar(
     sync_interval = get_sync_interval(
         interval=sync_interval, sleep_interval=sleep_interval
     )
+    try:
+        pod_id = os.environ[POLYAXON_KEYS_K8S_POD_ID]
+    except KeyError as e:
+        raise PolyaxonContainerException(
+            "Please make sure that this job has been "
+            "started by Polyaxon with all required context."
+        ) from e
 
     try:
         owner, project, run_uuid = get_run_info()
@@ -47,14 +53,10 @@ def start_sidecar(
         raise PolyaxonContainerException(e)
 
     client = RunClient(owner=owner, project=project, run_uuid=run_uuid)
-    pod_id = CLIENT_CONFIG.pod_id
-    if not pod_id:
-        raise PolyaxonContainerException(
-            "Please make sure that this job has been "
-            "started by Polyaxon with all required context."
-        )
+    k8s_manager = AsyncK8SManager(namespace=CLIENT_CONFIG.namespace, in_cluster=True)
+    await k8s_manager.setup()
+    pod = await k8s_manager.get_pod(pod_id, reraise=True)
 
-    k8s_manager = K8SManager(namespace=CLIENT_CONFIG.namespace, in_cluster=True)
     retry = 1
     is_running = True
     counter = 0
@@ -63,7 +65,16 @@ def start_sidecar(
         "last_logs_check": None,
     }
 
-    def monitor():
+    async def monitor():
+        if monitor_logs:
+            await sync_logs(
+                run_uuid=run_uuid,
+                k8s_manager=k8s_manager,
+                pod=pod,
+                last_time=None,
+                stream=True,
+                is_running=is_running,
+            )
         if monitor_outputs:
             last_check = state["last_artifacts_check"]
             state["last_artifacts_check"] = sync_artifacts(
@@ -73,27 +84,15 @@ def start_sidecar(
                 last_check=last_check, run_uuid=run_uuid, client=client,
             )
 
-        if monitor_logs:
-            state["last_logs_check"] = sync_logs(
-                k8s_manager=k8s_manager,
-                client=client,
-                last_check=state["last_logs_check"],
-                run_uuid=run_uuid,
-                pod_id=pod_id,
-                container_id=container_id,
-                owner=owner,
-                project=project,
-            )
-
     while is_running and retry <= 3:
-        time.sleep(sleep_interval)
+        await asyncio.sleep(sleep_interval)
         try:
-            is_running = is_pod_running(k8s_manager, pod_id, container_id)
+            is_running = await k8s_manager.is_pod_running(pod_id, container_id)
         except ApiException as e:
             retry += 1
-            time.sleep(1 * retry)
             logger.info("Exception %s" % repr(e))
             logger.info("Sleeping ...")
+            await asyncio.sleep(1 * retry)
             continue
 
         logger.debug("Syncing ...")
@@ -104,9 +103,11 @@ def start_sidecar(
         if counter == sync_interval:
             counter = 0
             try:
-                monitor()
+                await monitor()
             except Exception as e:
                 logger.warning("Polyaxon sidecar error: %e", e)
 
-    monitor()
+    await monitor()
     logger.info("Cleaning non main containers")
+    if k8s_manager:
+        await k8s_manager.close()
