@@ -35,7 +35,7 @@ class PolyaxonStore(StoreMixin):
 
     Used to download data from Polyaxon streams apis.
 
-    By default this store requires a valid run.
+    By default, this store requires a valid run.
     """
 
     URL = "/streams/v1/{namespace}/{owner}/{project}/runs/{uuid}/artifact"
@@ -162,8 +162,9 @@ class PolyaxonStore(StoreMixin):
             )
 
     def download_file(self, url, path, **kwargs):
-        local_path = get_path(
-            settings.CLIENT_CONFIG.archive_root, self._client.run_uuid,
+        local_path = kwargs.pop(
+            "path_to",
+            get_path(settings.CLIENT_CONFIG.archive_root, self._client.run_uuid,),
         )
         _local_path = local_path
         if path:
